Package: touch
Title: Tools of Utilization and Cost in Healthcare
Version: 0.1-7
Authors@R: c(
    person(given = "Wenjie", family = "Wang",
           role = c("aut", "cre"),
           email = "wang@wwenjie.org",
           comment = c(ORCID = "0000-0003-0363-3180")),
    person(given = "Yan", family = "Li", role = "aut"),
    person(given = "Jun", family = "Yan", role = "aut",
           comment = c(ORCID = "0000-0003-4401-7296"))
    )
Description: R implementation of the software tools developed in the H-CUP
    (Healthcare Cost and Utilization Project) <https://hcup-us.ahrq.gov>
    and AHRQ (Agency for Healthcare Research and Quality)
    <https://www.ahrq.gov>.  It currently contains functions for mapping ICD-9
    codes to the AHRQ comorbidity measures and translating ICD-9
    (resp. ICD-10) codes to ICD-10 (resp. ICD-9) codes based on GEM (General
    Equivalence Mappings) from CMS (Centers for Medicare and Medicaid
    Services).
Depends: R (>= 3.2.0)
LinkingTo: Rcpp
Imports: Rcpp
License: GPL (>= 3)
LazyData: yes
SysDataCompression: xz
URL: https://github.com/wenjie2wang/touch
BugReports: https://github.com/wenjie2wang/touch/issues
Encoding: UTF-8
NeedsCompilation: yes
Packaged: 2025-11-27 21:47:01 UTC; wenjie
Author: Wenjie Wang [aut, cre] (ORCID: <https://orcid.org/0000-0003-0363-3180>),
  Yan Li [aut],
  Jun Yan [aut] (ORCID: <https://orcid.org/0000-0003-4401-7296>)
Maintainer: Wenjie Wang <wang@wwenjie.org>
Repository: CRAN
Date/Publication: 2025-11-27 22:20:02 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 04:43:03 UTC; unix
Archs: touch.so.dSYM
