The icd-combination.txt file describes how to combine
the temporary 40 groups of ICD-9 coding defined in the
Format program at arhq website to get the ICD-9 coding
for each of 29 comorbidities used in cmbdGen.R.

The drg-combination.txt file contains how to combine
the temporary 24 groups of DRG coding defined in the
Format program at arhq website to get the DRG coding
for each of 29 comorbidities used in cmbdGen.R.

FormatCode.R uses readlines and regular expression to get
the 40 groups of ICD-9 coding and 24 groups of DRG coding
at arhq website and then combines them to generate DRG coding
and ICD-9 coding for cmbdGen.R.

input : sas-url.txt, drg-combination.txt, icd-combination.txt

output : icd.txt, drg.txt
